@@ -6,7 +6,6 @@ import requests
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
-from jnius import autoclass
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
@@ -23,17 +22,16 @@ class Network3Medusa():
         if 'eth_admin_fec_state' in raw_json:
             json_dict = json.loads(raw_json)
             first = True
-            for interface in json_dict:
+            for interface in json_dict['TABLE_interface']['ROW_interface']:
                 if first:
-                    print("first")
+                    print(interface)
                     first = False
                     raw_json=interface
-                    self.add_file_to_hedera(raw_json)
+                    self.add_file_to_hedera(str(raw_json))
                 else:
-                    print("not first")
+                    print(interface)
                     raw_json=interface
-                    self.append_file_to_hedera(raw_json)
-            print(self.receipt.toString())
+                    self.append_file_to_hedera(str(raw_json))
 
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
@@ -53,7 +51,7 @@ class Network3Medusa():
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
         fileContents = raw_json
-        resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(client)
+        resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
         self.nodeId = resp.nodeId.toString()
         receipt = resp.getReceipt(self.client)
